==> haskell-data-fix-0.3.2-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-fix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-fix
version:              0.3.2
visibility:           public
id:                   data-fix-0.3.2-3zutxYIf1gAGgK11zGPU61
key:                  data-fix-0.3.2-3zutxYIf1gAGgK11zGPU61
license:              BSD-3-Clause
maintainer:           <anton.kholomiov@gmail.com>
author:               Anton Kholomiov, Edward Kmett, Oleg Grenrus
stability:            Experimental
homepage:             https://github.com/spell-music/data-fix
synopsis:             Fixpoint data types
description:
    Fixpoint types and recursion schemes. If you define your AST as
    fixpoint type, you get fold and unfold operations for free.

    Thanks for contribution to: Matej Kollar, Herbert Valerio Riedel

category:             Data
abi:                  846a314e25b21212734a860f1ef02596
exposed:              True
exposed-modules:      Data.Fix
import-dirs:          /usr/lib/ghc-9.0.1/site-local/data-fix-0.3.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/data-fix-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/data-fix-0.3.2
hs-libraries:         HSdata-fix-0.3.2-3zutxYIf1gAGgK11zGPU61
depends:
    base-4.15.0.0 deepseq-1.4.5.0
    hashable-1.3.4.0-IEtvls2JnYMCj5AtMjw8bF

haddock-interfaces:   /usr/share/doc/haskell-data-fix/html/data-fix.haddock
haddock-html:         /usr/share/doc/haskell-data-fix/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-fix-0.3.2-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-fix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-fix
version:              0.3.2
visibility:           public
id:                   data-fix-0.3.2-2JSIeUfC6HLG1KlmaFPdRQ
key:                  data-fix-0.3.2-2JSIeUfC6HLG1KlmaFPdRQ
license:              BSD-3-Clause
maintainer:           <anton.kholomiov@gmail.com>
author:               Anton Kholomiov, Edward Kmett, Oleg Grenrus
stability:            Experimental
homepage:             https://github.com/spell-music/data-fix
synopsis:             Fixpoint data types
description:
    Fixpoint types and recursion schemes. If you define your AST as
    fixpoint type, you get fold and unfold operations for free.

    Thanks for contribution to: Matej Kollar, Herbert Valerio Riedel

category:             Data
abi:                  8e0e819b8c2ae1b729ac22aff2535807
exposed:              True
exposed-modules:      Data.Fix
import-dirs:          /usr/lib/ghc-9.0.1/site-local/data-fix-0.3.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/data-fix-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/data-fix-0.3.2
hs-libraries:         HSdata-fix-0.3.2-2JSIeUfC6HLG1KlmaFPdRQ
depends:
    base-4.15.0.0 deepseq-1.4.5.0
    hashable-1.3.4.1-8PH3sYtWVv45iE53pOmUfm

haddock-interfaces:   /usr/share/doc/haskell-data-fix/html/data-fix.haddock
haddock-html:         /usr/share/doc/haskell-data-fix/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
